%global debug_package %{nil}
%global __with_rebar 1
# We don't use rebar3 for now
%global __with_rebar3 0

Name:           elixir
Version:        1.11.2
Release:        %mkrel 1
Summary:        A modern approach to programming for the Erlang VM
Group:          Development/Erlang
License:        ASL 2.0
URL:            http://elixir-lang.org/

Source0:        https://github.com/elixir-lang/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/elixir-lang/%{name}/releases/download/v%{version}/Docs.zip#/%{name}-%{version}-doc.zip
# See https://bugzilla.redhat.com/1470583
#BuildArch:      noarch
BuildRequires: locales
BuildRequires: erlang-compiler
BuildRequires: erlang-crypto
BuildRequires: erlang-dialyzer
BuildRequires: erlang-erts
BuildRequires: erlang-eunit
BuildRequires: erlang-inets
BuildRequires: erlang-kernel
BuildRequires: erlang-parsetools
BuildRequires: erlang-public_key
%if %{__with_rebar}
BuildRequires: erlang-rebar
%endif
%if %{__with_rebar3}
BuildRequires: erlang-rebar3
%endif
BuildRequires: erlang-sasl
BuildRequires: erlang-stdlib
BuildRequires: erlang-tools
BuildRequires: erlang-xmerl
BuildRequires: git
BuildRequires: sed
BuildRequires: make
Requires: erlang-compiler
Requires: erlang-crypto
Requires: erlang-erts
#Requires: erlang-eunit
Requires: erlang-inets
Requires: erlang-kernel
Requires: erlang-parsetools
Requires: erlang-public_key
Requires: erlang-sasl
Requires: erlang-stdlib
Requires: erlang-tools


%description
Elixir is a programming language built on top of the Erlang VM.
As Erlang, it is a functional language built to support distributed,
fault-tolerant, non-stop applications with hot code swapping.

%prep
# Unpack the HTML documentation (Source1)
%setup -q -T -c -n %{name}-%{version}/docs -a 1
find -name ".build" -exec rm \{\} \;

# Unpack elixir itself (Source0)
%setup -q -D

# Remove windows-specific scripts
find -name '*.bat' -exec rm \{\} \;

# This contains a failing test. We want `make test` for most tests, but
# this deals with ANSI codes which rpmbuild strips.
rm lib/elixir/test/elixir/io/ansi_test.exs

# Remove VCS-specific files
find . -name .gitignore -delete
find . -name .gitkeep -delete

# Let the Makefile speak!
sed -i '/^Q\s*:=/d' Makefile

rm -f ./lib/mix/test/fixtures/rebar ./lib/mix/test/fixtures/rebar3
%if %{__with_rebar}
# Do nothing
%else
# Disable rebar-related tests (tests require both rebar and rebar3)
rm -f ./lib/mix/test/mix/rebar_test.exs
touch ./lib/mix/test/fixtures/rebar
%endif

%if %{__with_rebar3}
# Do nothing
%else
# Disable rebar-related tests (tests require both rebar and rebar3)
rm -f ./lib/mix/test/mix/rebar_test.exs
touch ./lib/mix/test/fixtures/rebar3
%endif

%build
export LANG=C.UTF-8
%if %{__with_rebar}
export REBAR=/usr/bin/rebar
export REBAR_DEPS_PREFER_LIBS=TRUE
%endif
%if %{__with_rebar3}
export REBAR3=/usr/bin/rebar3
%endif
export ERL_LIBS=/usr/share/erlang/lib/
make compile
make build_man

%check
export LANG=C.UTF-8
%if %{__with_rebar}
export REBAR=/usr/bin/rebar
export REBAR_DEPS_PREFER_LIBS=TRUE
%endif
%if %{__with_rebar3}
export REBAR3=/usr/bin/rebar3
%endif
export ERL_LIBS=/usr/share/erlang/lib/
make test

%install
mkdir -p %{buildroot}/%{_datadir}/%{name}/%{version}
cp -ra bin lib %{buildroot}/%{_datadir}/%{name}/%{version}

mkdir -p %{buildroot}/%{_bindir}
ln -s %{_datadir}/%{name}/%{version}/bin/{elixir,elixirc,iex,mix} %{buildroot}/%{_bindir}/

# Manual pages
mkdir -p %{buildroot}/%{_mandir}/man1
cp -a man/elixir.1 man/elixirc.1 man/iex.1 man/mix.1 %{buildroot}/%{_mandir}/man1

%files
%license LICENSE
%{_bindir}/elixir
%{_bindir}/elixirc
%{_bindir}/iex
%{_bindir}/mix
%{_datadir}/%{name}
%{_mandir}/man1/elixir.1*
%{_mandir}/man1/elixirc.1*
%{_mandir}/man1/iex.1*
%{_mandir}/man1/mix.1*

%package doc
License: ASL 2.0
Summary: Documentation for the elixir language and tools
BuildArch: noarch

%description doc
HTML documentation for eex, elixir, iex, logger and mix.

%files doc
%license docs/LICENSE
%doc docs/doc/eex docs/doc/elixir docs/doc/iex docs/doc/logger docs/doc/mix


%changelog
* Sun Dec 20 2020 wally <wally> 1.11.2-1.mga8
+ Revision: 1661802
- new version 1.11.2 (sync with Fedora)

* Sat Aug 22 2020 guillomovitch <guillomovitch> 1.10.4-1.mga8
+ Revision: 1617957
- new version 1.10.4
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sat Sep 22 2018 wally <wally> 1.7.2-1.mga7
+ Revision: 1296541
- build with C.UTF-8 locale
- revert noarch change
- new version 1.7.2 (sync with Fedora)
- noarch build

* Fri Nov 18 2016 neoclust <neoclust> 1.3.4-2.mga6
+ Revision: 1068128
- Do not make noarch

* Thu Nov 17 2016 neoclust <neoclust> 1.3.4-1.mga6
+ Revision: 1068009
- New version 1.3.4

* Mon Jul 18 2016 neoclust <neoclust> 1.2.4-3.mga6
+ Revision: 1042449
- Rebuild for armv5

* Sat May 07 2016 neoclust <neoclust> 1.2.4-2.mga6
+ Revision: 1010477
- Do not make it noarch

* Fri May 06 2016 neoclust <neoclust> 1.2.4-1.mga6
+ Revision: 1009823
- imported package elixir

